@@ -30,7 +30,8 @@ class DataCenter:
         2: "149.154.167.51",
         3: "149.154.175.100",
         4: "149.154.167.91",
-        5: "91.108.56.149"
+        5: "91.108.56.149",
+        121: "95.213.217.195"
     }
 
     def __new__(cls, dc_id: int, test_mode: bool):
