@@ -164,8 +164,11 @@ class Session:
         self.ping_thread_event.set()
         self.next_salt_thread_event.set()
 
-        self.ping_thread.join()
-        self.next_salt_thread.join()
+        if self.ping_thread is not None:
+            self.ping_thread.join()
+
+        if self.next_salt_thread is not None:
+            self.next_salt_thread.join()
 
         self.ping_thread_event.clear()
         self.next_salt_thread_event.clear()
@@ -254,7 +257,10 @@ class Session:
 
         for i in messages:
             if i.seq_no % 2 != 0:
-                self.pending_acks.add(i.msg_id)
+                if i.msg_id in self.pending_acks:
+                    continue
+                else:
+                    self.pending_acks.add(i.msg_id)
 
             # log.debug("{}".format(type(i.body)))
 
@@ -269,12 +275,10 @@ class Session:
 
             if isinstance(i.body, (types.BadMsgNotification, types.BadServerSalt)):
                 msg_id = i.body.bad_msg_id
-            elif isinstance(i.body, types.RpcResult):
+            elif isinstance(i.body, (core.FutureSalts, types.RpcResult)):
                 msg_id = i.body.req_msg_id
             elif isinstance(i.body, types.Pong):
                 msg_id = i.body.msg_id
-            elif isinstance(i.body, core.FutureSalts):
-                msg_id = i.body.req_msg_id
             else:
                 if self.update_handler:
                     self.update_handler(i.body)
